/****************************************************************************
** Meta object code from reading C++ file 'board.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kshisen-17.12.3/src/board.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'board.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KShisen__Board_t {
    QByteArrayData data[24];
    char stringdata0[314];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KShisen__Board_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KShisen__Board_t qt_meta_stringdata_KShisen__Board = {
    {
QT_MOC_LITERAL(0, 0, 14), // "KShisen::Board"
QT_MOC_LITERAL(1, 15, 11), // "markMatched"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 14), // "newGameStarted"
QT_MOC_LITERAL(4, 43, 7), // "changed"
QT_MOC_LITERAL(5, 51, 16), // "tileCountChanged"
QT_MOC_LITERAL(6, 68, 9), // "endOfGame"
QT_MOC_LITERAL(7, 78, 7), // "resized"
QT_MOC_LITERAL(8, 86, 11), // "invalidMove"
QT_MOC_LITERAL(9, 98, 15), // "tilesDoNotMatch"
QT_MOC_LITERAL(10, 114, 11), // "selectATile"
QT_MOC_LITERAL(11, 126, 11), // "selectAMove"
QT_MOC_LITERAL(12, 138, 19), // "selectAMatchingTile"
QT_MOC_LITERAL(13, 158, 18), // "cheatStatusChanged"
QT_MOC_LITERAL(14, 177, 7), // "newGame"
QT_MOC_LITERAL(15, 185, 15), // "setPauseEnabled"
QT_MOC_LITERAL(16, 201, 7), // "enabled"
QT_MOC_LITERAL(17, 209, 16), // "setSoundsEnabled"
QT_MOC_LITERAL(18, 226, 12), // "loadSettings"
QT_MOC_LITERAL(19, 239, 11), // "loadTileset"
QT_MOC_LITERAL(20, 251, 13), // "pathToTileset"
QT_MOC_LITERAL(21, 265, 14), // "loadBackground"
QT_MOC_LITERAL(22, 280, 16), // "pathToBackground"
QT_MOC_LITERAL(23, 297, 16) // "undrawConnection"

    },
    "KShisen::Board\0markMatched\0\0newGameStarted\0"
    "changed\0tileCountChanged\0endOfGame\0"
    "resized\0invalidMove\0tilesDoNotMatch\0"
    "selectATile\0selectAMove\0selectAMatchingTile\0"
    "cheatStatusChanged\0newGame\0setPauseEnabled\0"
    "enabled\0setSoundsEnabled\0loadSettings\0"
    "loadTileset\0pathToTileset\0loadBackground\0"
    "pathToBackground\0undrawConnection"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KShisen__Board[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      19,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      12,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  109,    2, 0x06 /* Public */,
       3,    0,  110,    2, 0x06 /* Public */,
       4,    0,  111,    2, 0x06 /* Public */,
       5,    0,  112,    2, 0x06 /* Public */,
       6,    0,  113,    2, 0x06 /* Public */,
       7,    0,  114,    2, 0x06 /* Public */,
       8,    0,  115,    2, 0x06 /* Public */,
       9,    0,  116,    2, 0x06 /* Public */,
      10,    0,  117,    2, 0x06 /* Public */,
      11,    0,  118,    2, 0x06 /* Public */,
      12,    0,  119,    2, 0x06 /* Public */,
      13,    0,  120,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      14,    0,  121,    2, 0x0a /* Public */,
      15,    1,  122,    2, 0x0a /* Public */,
      17,    1,  125,    2, 0x0a /* Public */,
      18,    0,  128,    2, 0x0a /* Public */,
      19,    1,  129,    2, 0x0a /* Public */,
      21,    1,  132,    2, 0x0a /* Public */,
      23,    0,  135,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void, QMetaType::Bool,   16,
    QMetaType::Void,
    QMetaType::Bool, QMetaType::QString,   20,
    QMetaType::Bool, QMetaType::QString,   22,
    QMetaType::Void,

       0        // eod
};

void KShisen::Board::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Board *_t = static_cast<Board *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->markMatched(); break;
        case 1: _t->newGameStarted(); break;
        case 2: _t->changed(); break;
        case 3: _t->tileCountChanged(); break;
        case 4: _t->endOfGame(); break;
        case 5: _t->resized(); break;
        case 6: _t->invalidMove(); break;
        case 7: _t->tilesDoNotMatch(); break;
        case 8: _t->selectATile(); break;
        case 9: _t->selectAMove(); break;
        case 10: _t->selectAMatchingTile(); break;
        case 11: _t->cheatStatusChanged(); break;
        case 12: _t->newGame(); break;
        case 13: _t->setPauseEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->setSoundsEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->loadSettings(); break;
        case 16: { bool _r = _t->loadTileset((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->loadBackground((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->undrawConnection(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Board::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Board::markMatched)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Board::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Board::newGameStarted)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Board::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Board::changed)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Board::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Board::tileCountChanged)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Board::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Board::endOfGame)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Board::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Board::resized)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (Board::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Board::invalidMove)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (Board::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Board::tilesDoNotMatch)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (Board::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Board::selectATile)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (Board::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Board::selectAMove)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (Board::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Board::selectAMatchingTile)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (Board::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Board::cheatStatusChanged)) {
                *result = 11;
                return;
            }
        }
    }
}

const QMetaObject KShisen::Board::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KShisen__Board.data,
      qt_meta_data_KShisen__Board,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KShisen::Board::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KShisen::Board::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KShisen__Board.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KShisen::Board::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void KShisen::Board::markMatched()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KShisen::Board::newGameStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KShisen::Board::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KShisen::Board::tileCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KShisen::Board::endOfGame()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KShisen::Board::resized()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KShisen::Board::invalidMove()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KShisen::Board::tilesDoNotMatch()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KShisen::Board::selectATile()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KShisen::Board::selectAMove()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KShisen::Board::selectAMatchingTile()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KShisen::Board::cheatStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
