/****************************************************************************
** Meta object code from reading C++ file 'app.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kshisen-17.12.3/src/app.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'app.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KShisen__App_t {
    QByteArrayData data[24];
    char stringdata0[328];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KShisen__App_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KShisen__App_t qt_meta_stringdata_KShisen__App = {
    {
QT_MOC_LITERAL(0, 0, 12), // "KShisen::App"
QT_MOC_LITERAL(1, 13, 13), // "invokeNewGame"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 13), // "slotEndOfGame"
QT_MOC_LITERAL(4, 42, 11), // "updateItems"
QT_MOC_LITERAL(5, 54, 17), // "updateTimeDisplay"
QT_MOC_LITERAL(6, 72, 17), // "updateTileDisplay"
QT_MOC_LITERAL(7, 90, 18), // "updateCheatDisplay"
QT_MOC_LITERAL(8, 109, 18), // "showSettingsDialog"
QT_MOC_LITERAL(9, 128, 21), // "notifyTilesDoNotMatch"
QT_MOC_LITERAL(10, 150, 17), // "notifyInvalidMove"
QT_MOC_LITERAL(11, 168, 17), // "notifySelectATile"
QT_MOC_LITERAL(12, 186, 25), // "notifySelectAMatchingTile"
QT_MOC_LITERAL(13, 212, 17), // "notifySelectAMove"
QT_MOC_LITERAL(14, 230, 7), // "newGame"
QT_MOC_LITERAL(15, 238, 11), // "restartGame"
QT_MOC_LITERAL(16, 250, 11), // "togglePause"
QT_MOC_LITERAL(17, 262, 15), // "setPauseEnabled"
QT_MOC_LITERAL(18, 278, 7), // "enabled"
QT_MOC_LITERAL(19, 286, 4), // "undo"
QT_MOC_LITERAL(20, 291, 4), // "redo"
QT_MOC_LITERAL(21, 296, 4), // "hint"
QT_MOC_LITERAL(22, 301, 11), // "keyBindings"
QT_MOC_LITERAL(23, 313, 14) // "showHighscores"

    },
    "KShisen::App\0invokeNewGame\0\0slotEndOfGame\0"
    "updateItems\0updateTimeDisplay\0"
    "updateTileDisplay\0updateCheatDisplay\0"
    "showSettingsDialog\0notifyTilesDoNotMatch\0"
    "notifyInvalidMove\0notifySelectATile\0"
    "notifySelectAMatchingTile\0notifySelectAMove\0"
    "newGame\0restartGame\0togglePause\0"
    "setPauseEnabled\0enabled\0undo\0redo\0"
    "hint\0keyBindings\0showHighscores"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KShisen__App[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      21,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  119,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,  120,    2, 0x08 /* Private */,
       4,    0,  121,    2, 0x08 /* Private */,
       5,    0,  122,    2, 0x08 /* Private */,
       6,    0,  123,    2, 0x08 /* Private */,
       7,    0,  124,    2, 0x08 /* Private */,
       8,    0,  125,    2, 0x08 /* Private */,
       9,    0,  126,    2, 0x08 /* Private */,
      10,    0,  127,    2, 0x08 /* Private */,
      11,    0,  128,    2, 0x08 /* Private */,
      12,    0,  129,    2, 0x08 /* Private */,
      13,    0,  130,    2, 0x08 /* Private */,
      14,    0,  131,    2, 0x08 /* Private */,
      15,    0,  132,    2, 0x08 /* Private */,
      16,    0,  133,    2, 0x08 /* Private */,
      17,    1,  134,    2, 0x08 /* Private */,
      19,    0,  137,    2, 0x08 /* Private */,
      20,    0,  138,    2, 0x08 /* Private */,
      21,    0,  139,    2, 0x08 /* Private */,
      22,    0,  140,    2, 0x08 /* Private */,
      23,    0,  141,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KShisen::App::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        App *_t = static_cast<App *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->invokeNewGame(); break;
        case 1: _t->slotEndOfGame(); break;
        case 2: _t->updateItems(); break;
        case 3: _t->updateTimeDisplay(); break;
        case 4: _t->updateTileDisplay(); break;
        case 5: _t->updateCheatDisplay(); break;
        case 6: _t->showSettingsDialog(); break;
        case 7: _t->notifyTilesDoNotMatch(); break;
        case 8: _t->notifyInvalidMove(); break;
        case 9: _t->notifySelectATile(); break;
        case 10: _t->notifySelectAMatchingTile(); break;
        case 11: _t->notifySelectAMove(); break;
        case 12: _t->newGame(); break;
        case 13: _t->restartGame(); break;
        case 14: _t->togglePause(); break;
        case 15: _t->setPauseEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 16: _t->undo(); break;
        case 17: _t->redo(); break;
        case 18: _t->hint(); break;
        case 19: _t->keyBindings(); break;
        case 20: _t->showHighscores(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (App::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&App::invokeNewGame)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject KShisen::App::staticMetaObject = {
    { &KXmlGuiWindow::staticMetaObject, qt_meta_stringdata_KShisen__App.data,
      qt_meta_data_KShisen__App,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KShisen::App::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KShisen::App::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KShisen__App.stringdata0))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KShisen::App::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void KShisen::App::invokeNewGame()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
