#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'settings.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGS_H
#define UI_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_Settings
{
public:
    QVBoxLayout *vboxLayout;
    QCheckBox *kcfg_Gravity;
    QCheckBox *kcfg_Solvable;
    QCheckBox *kcfg_ChineseStyle;
    QCheckBox *kcfg_TilesCanSlide;
    QGroupBox *difficulty_groupBox;
    QVBoxLayout *verticalLayout;
    QSlider *kcfg_Level;
    QHBoxLayout *horizontalLayout;
    QLabel *textLabel1;
    QSpacerItem *horizontalSpacer;
    QLabel *textLabel3;
    QGroupBox *speed_groupBox;
    QVBoxLayout *verticalLayout_2;
    QSlider *kcfg_Speed;
    QHBoxLayout *horizontalLayout_2;
    QLabel *textLabel4;
    QSpacerItem *horizontalSpacer_2;
    QLabel *textLabel6;
    QGroupBox *size_groupBox;
    QVBoxLayout *verticalLayout_3;
    QSlider *kcfg_Size;
    QHBoxLayout *horizontalLayout_3;
    QLabel *textLabel8;
    QSpacerItem *horizontalSpacer_3;
    QLabel *textLabel9;
    QSpacerItem *horizontalSpacer_4;
    QLabel *textLabel7;
    QSpacerItem *horizontalSpacer_5;
    QLabel *textLabel10;
    QSpacerItem *horizontalSpacer_6;
    QLabel *textLabel11;
    QSpacerItem *horizontalSpacer_7;
    QLabel *textLabel12;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *Settings)
    {
        if (Settings->objectName().isEmpty())
            Settings->setObjectName(QStringLiteral("Settings"));
        Settings->resize(536, 428);
        vboxLayout = new QVBoxLayout(Settings);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        kcfg_Gravity = new QCheckBox(Settings);
        kcfg_Gravity->setObjectName(QStringLiteral("kcfg_Gravity"));

        vboxLayout->addWidget(kcfg_Gravity);

        kcfg_Solvable = new QCheckBox(Settings);
        kcfg_Solvable->setObjectName(QStringLiteral("kcfg_Solvable"));

        vboxLayout->addWidget(kcfg_Solvable);

        kcfg_ChineseStyle = new QCheckBox(Settings);
        kcfg_ChineseStyle->setObjectName(QStringLiteral("kcfg_ChineseStyle"));

        vboxLayout->addWidget(kcfg_ChineseStyle);

        kcfg_TilesCanSlide = new QCheckBox(Settings);
        kcfg_TilesCanSlide->setObjectName(QStringLiteral("kcfg_TilesCanSlide"));

        vboxLayout->addWidget(kcfg_TilesCanSlide);

        difficulty_groupBox = new QGroupBox(Settings);
        difficulty_groupBox->setObjectName(QStringLiteral("difficulty_groupBox"));
        verticalLayout = new QVBoxLayout(difficulty_groupBox);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        kcfg_Level = new QSlider(difficulty_groupBox);
        kcfg_Level->setObjectName(QStringLiteral("kcfg_Level"));
        kcfg_Level->setMaximum(2);
        kcfg_Level->setPageStep(1);
        kcfg_Level->setValue(1);
        kcfg_Level->setOrientation(Qt::Horizontal);
        kcfg_Level->setTickPosition(QSlider::TicksBelow);

        verticalLayout->addWidget(kcfg_Level);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        textLabel1 = new QLabel(difficulty_groupBox);
        textLabel1->setObjectName(QStringLiteral("textLabel1"));

        horizontalLayout->addWidget(textLabel1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        textLabel3 = new QLabel(difficulty_groupBox);
        textLabel3->setObjectName(QStringLiteral("textLabel3"));
        textLabel3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout->addWidget(textLabel3);


        verticalLayout->addLayout(horizontalLayout);


        vboxLayout->addWidget(difficulty_groupBox);

        speed_groupBox = new QGroupBox(Settings);
        speed_groupBox->setObjectName(QStringLiteral("speed_groupBox"));
        verticalLayout_2 = new QVBoxLayout(speed_groupBox);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        kcfg_Speed = new QSlider(speed_groupBox);
        kcfg_Speed->setObjectName(QStringLiteral("kcfg_Speed"));
        kcfg_Speed->setMaximum(4);
        kcfg_Speed->setPageStep(1);
        kcfg_Speed->setValue(2);
        kcfg_Speed->setOrientation(Qt::Horizontal);
        kcfg_Speed->setTickPosition(QSlider::TicksBelow);

        verticalLayout_2->addWidget(kcfg_Speed);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QStringLiteral("horizontalLayout_2"));
        textLabel4 = new QLabel(speed_groupBox);
        textLabel4->setObjectName(QStringLiteral("textLabel4"));

        horizontalLayout_2->addWidget(textLabel4);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        textLabel6 = new QLabel(speed_groupBox);
        textLabel6->setObjectName(QStringLiteral("textLabel6"));
        textLabel6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_2->addWidget(textLabel6);


        verticalLayout_2->addLayout(horizontalLayout_2);


        vboxLayout->addWidget(speed_groupBox);

        size_groupBox = new QGroupBox(Settings);
        size_groupBox->setObjectName(QStringLiteral("size_groupBox"));
        verticalLayout_3 = new QVBoxLayout(size_groupBox);
        verticalLayout_3->setObjectName(QStringLiteral("verticalLayout_3"));
        kcfg_Size = new QSlider(size_groupBox);
        kcfg_Size->setObjectName(QStringLiteral("kcfg_Size"));
        kcfg_Size->setMinimum(0);
        kcfg_Size->setMaximum(5);
        kcfg_Size->setPageStep(1);
        kcfg_Size->setValue(2);
        kcfg_Size->setOrientation(Qt::Horizontal);
        kcfg_Size->setTickPosition(QSlider::TicksBelow);

        verticalLayout_3->addWidget(kcfg_Size);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        textLabel8 = new QLabel(size_groupBox);
        textLabel8->setObjectName(QStringLiteral("textLabel8"));

        horizontalLayout_3->addWidget(textLabel8);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);

        textLabel9 = new QLabel(size_groupBox);
        textLabel9->setObjectName(QStringLiteral("textLabel9"));
        textLabel9->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        horizontalLayout_3->addWidget(textLabel9);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_4);

        textLabel7 = new QLabel(size_groupBox);
        textLabel7->setObjectName(QStringLiteral("textLabel7"));
        textLabel7->setAlignment(Qt::AlignCenter);

        horizontalLayout_3->addWidget(textLabel7);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_5);

        textLabel10 = new QLabel(size_groupBox);
        textLabel10->setObjectName(QStringLiteral("textLabel10"));
        textLabel10->setAlignment(Qt::AlignCenter);

        horizontalLayout_3->addWidget(textLabel10);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_6);

        textLabel11 = new QLabel(size_groupBox);
        textLabel11->setObjectName(QStringLiteral("textLabel11"));
        textLabel11->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_3->addWidget(textLabel11);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_7);

        textLabel12 = new QLabel(size_groupBox);
        textLabel12->setObjectName(QStringLiteral("textLabel12"));
        textLabel12->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout_3->addWidget(textLabel12);


        verticalLayout_3->addLayout(horizontalLayout_3);


        vboxLayout->addWidget(size_groupBox);

        spacerItem = new QSpacerItem(507, 31, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem);


        retranslateUi(Settings);

        QMetaObject::connectSlotsByName(Settings);
    } // setupUi

    void retranslateUi(QWidget *Settings)
    {
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_Gravity->setWhatsThis(tr2i18n("<b>Gravity</b><p>Checking this makes the game even harder: If a tile is removed, all tiles lying above it will fall down one step.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        kcfg_Gravity->setText(tr2i18n("Gravity", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_Solvable->setWhatsThis(tr2i18n("<b>Create solvable games only</b><p>If checked, you will only be presented with games that are possible to solve.</p><p>Note: Even in solvable games you can fail to complete if you remove the tiles in the wrong order.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        kcfg_Solvable->setText(tr2i18n("Create solvable games only", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_ChineseStyle->setWhatsThis(tr2i18n("<b>Use Chinese style: any flower match any flower, any season match any season</b><p>Use the traditional rules for matching the tiles. Previous version of the game used to allow only exact tiles matches, which is inconsistent with Mah-jongg rules. It is recommended to keep this option checked.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        kcfg_ChineseStyle->setText(tr2i18n("Use Chinese style: any flower match any flower, any season match any season", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        kcfg_TilesCanSlide->setWhatsThis(tr2i18n("<b>Tiles can slide, but you can connect only in 2 lines instead of 3</b><p>This option changes the rules to the point where it almost becomes a completely different game. When it is active, you can only remove the tiles if they can be connected by a line consisting of only two segments instead of the customary three. However, you are allowed to slide the tiles on the board, if the row or column where they are placed has some empty space. To make a sliding move, you have to click on the tile containing the column or row that can slide, and then on the matching tile. If there are two possible sliding moves, you will have to click on one of the two connecting lines to choose your preferred move.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        kcfg_TilesCanSlide->setText(tr2i18n("Tiles can slide, but you can connect only in 2 lines instead of 3", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        difficulty_groupBox->setWhatsThis(tr2i18n("<b>Board Difficulty</b><p>The slider controls the difficulty of the board from Easy to Hard.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        difficulty_groupBox->setTitle(tr2i18n("Board Difficulty", Q_NULLPTR));
        textLabel1->setText(tr2i18n("Easy", Q_NULLPTR));
        textLabel3->setText(tr2i18n("Hard", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        speed_groupBox->setWhatsThis(tr2i18n("<b>Piece Removal Speed</b><p>Adjusting this slider alters the speed at which the pieces are removed from the screen after a match has been made.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        speed_groupBox->setTitle(tr2i18n("Piece Removal Speed", Q_NULLPTR));
        textLabel4->setText(tr2i18n("Slow", Q_NULLPTR));
        textLabel6->setText(tr2i18n("Fast", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        size_groupBox->setWhatsThis(tr2i18n("<b>Board Size</b><p>This slider allows you to change the number of tiles on the board. The more tiles you have, the harder (and longer) the game will be.</p>", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        size_groupBox->setTitle(tr2i18n("Board Size", Q_NULLPTR));
        textLabel8->setText(tr2i18n("14x6", Q_NULLPTR));
        textLabel9->setText(tr2i18n("16x9", Q_NULLPTR));
        textLabel7->setText(tr2i18n("18x8", Q_NULLPTR));
        textLabel10->setText(tr2i18n("24x12", Q_NULLPTR));
        textLabel11->setText(tr2i18n("26x14", Q_NULLPTR));
        textLabel12->setText(tr2i18n("30x16", Q_NULLPTR));
        Q_UNUSED(Settings);
    } // retranslateUi

};

namespace Ui {
    class Settings: public Ui_Settings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGS_H

